<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="1.1" language="zh-TW" sourcelanguage="en">
  <context>
    <name>Ship</name>
    <message>
      <location filename="InitGui.py" line="65"/>
      <source>Ship design</source>
      <translation>船舶設計</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="68"/>
      <source>Weights</source>
      <translation>重量</translation>
    </message>
    <message>
      <location filename="Instance.py" line="47"/>
      <source>True if it is a valid ship instance, False otherwise</source>
      <translation type="unfinished">True if it is a valid ship instance, False otherwise</translation>
    </message>
    <message>
      <location filename="Instance.py" line="56"/>
      <source>Ship length [m]</source>
      <translation>船舶長度 [m]</translation>
    </message>
    <message>
      <location filename="Instance.py" line="64"/>
      <source>Ship breadth [m]</source>
      <translation>船舶廣度 [m]</translation>
    </message>
    <message>
      <location filename="Instance.py" line="72"/>
      <source>Ship draft [m]</source>
      <translation>船舶吃水 [m]</translation>
    </message>
    <message>
      <location filename="Instance.py" line="82"/>
      <source>Set of external faces of the ship hull</source>
      <translation type="unfinished">Set of external faces of the ship hull</translation>
    </message>
    <message>
      <location filename="Instance.py" line="90"/>
      <source>Set of weight instances</source>
      <translation type="unfinished">Set of weight instances</translation>
    </message>
    <message>
      <location filename="Instance.py" line="98"/>
      <source>Set of tank instances</source>
      <translation type="unfinished">Set of tank instances</translation>
    </message>
    <message>
      <location filename="Instance.py" line="106"/>
      <source>Set of load conditions</source>
      <translation type="unfinished">Set of load conditions</translation>
    </message>
  </context>
  <context>
    <name>Ship_AreasCurve</name>
    <message>
      <location filename="ShipGui.py" line="97"/>
      <source>Areas curve</source>
      <translation type="unfinished">Areas curve</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="100"/>
      <source>Plot the transversal areas curve</source>
      <translation type="unfinished">Plot the transversal areas curve</translation>
    </message>
  </context>
  <context>
    <name>Ship_CreateShip</name>
    <message>
      <location filename="ShipGui.py" line="63"/>
      <source>Create a new ship</source>
      <translation>建立新的船舶</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="66"/>
      <source>Create a new ship instance on top of the hull geometry</source>
      <translation type="unfinished">Create a new ship instance on top of the hull geometry</translation>
    </message>
  </context>
  <context>
    <name>Ship_Hydrostatics</name>
    <message>
      <location filename="ShipGui.py" line="114"/>
      <source>Hydrostatics</source>
      <translation>流體靜力學</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="117"/>
      <source>Plot the ship hydrostatics</source>
      <translation type="unfinished">Plot the ship hydrostatics</translation>
    </message>
  </context>
  <context>
    <name>Ship_LoadExample</name>
    <message>
      <location filename="ShipGui.py" line="46"/>
      <source>Load an example ship geometry</source>
      <translation>載入範例船舶幾何</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="49"/>
      <source>Load an example ship hull geometry.</source>
      <translation type="unfinished">Load an example ship hull geometry.</translation>
    </message>
  </context>
  <context>
    <name>Ship_OutlineDraw</name>
    <message>
      <location filename="ShipGui.py" line="80"/>
      <source>Outline draw</source>
      <translation>輪廓繪製</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="83"/>
      <source>Plots the ship hull outline draw</source>
      <translation type="unfinished">Plots the ship hull outline draw</translation>
    </message>
  </context>
  <context>
    <name>ship_areas</name>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>Draft</source>
      <translation>吃水</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="323"/>
      <source>Displacement</source>
      <translation>位移</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="347"/>
      <source>Areas curve tool draft selected [m]</source>
      <translation type="unfinished">Areas curve tool draft selected [m]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="223"/>
      <source>Plot the transversal areas curve</source>
      <translation type="unfinished">Plot the transversal areas curve</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="362"/>
      <source>Areas curve tool trim selected [deg]</source>
      <translation type="unfinished">Areas curve tool trim selected [deg]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="233"/>
      <source>Trim angle</source>
      <translation>修剪角度</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="238"/>
      <source>Number of points</source>
      <translation>點數</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="377"/>
      <source>Areas curve tool number of points</source>
      <translation type="unfinished">Areas curve tool number of points</translation>
    </message>
  </context>
  <context>
    <name>ship_capacity</name>
    <message>
      <location filename="ShipGui.py" line="165"/>
      <source>Tank capacity curve</source>
      <translation type="unfinished">Tank capacity curve</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="168"/>
      <source>Plot the tank capacity curve (level-volume curve)</source>
      <translation type="unfinished">Plot the tank capacity curve (level-volume curve)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="159"/>
      <source>Plot the tank capacity curve</source>
      <translation type="unfinished">Plot the tank capacity curve</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="164"/>
      <source>Number of points</source>
      <translation>點數</translation>
    </message>
  </context>
  <context>
    <name>ship_console</name>
    <message>
      <location filename="TaskPanel.py" line="162"/>
      <source>Please create or load a ship hull geometry before using this tool</source>
      <translation type="unfinished">Please create or load a ship hull geometry before using this tool</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="156"/>
      <source>Ship objects can only be created on top of hull geometry (no solid found at selected objects)</source>
      <translation type="unfinished">Ship objects can only be created on top of hull geometry (no solid found at selected objects)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="98"/>
      <source>Computing hydrostatics</source>
      <translation>運算流體靜力學</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="490"/>
      <source>Computing external faces</source>
      <translation type="unfinished">Computing external faces</translation>
    </message>
    <message>
      <location filename="Preview.py" line="58"/>
      <source>Computing sections</source>
      <translation type="unfinished">Computing sections</translation>
    </message>
    <message>
      <location filename="Preview.py" line="131"/>
      <source>Any valid ship section found</source>
      <translation type="unfinished">Any valid ship section found</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="137"/>
      <source>Ship objects can only be created on top of hull geometry (no objects selected)</source>
      <translation type="unfinished">Ship objects can only be created on top of hull geometry (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="202"/>
      <source>A ship instance must be selected before using this tool (no objects selected)</source>
      <translation type="unfinished">A ship instance must be selected before using this tool (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="218"/>
      <source>More than one ship have been selected (the extra ships will be ignored)</source>
      <translation type="unfinished">More than one ship have been selected (the extra ships will be ignored)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="228"/>
      <source>A ship instance must be selected before using this tool (no valid ship found at the selected objects)</source>
      <translation type="unfinished">A ship instance must be selected before using this tool (no valid ship found at the selected objects)</translation>
    </message>
    <message>
      <location filename="PlotAux.py" line="61"/>
      <source>Plot module is disabled, so I cannot perform the plot</source>
      <translation type="unfinished">Plot module is disabled, so I cannot perform the plot</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="197"/>
      <source>A ship instance must be selected before use this tool (no objects selected)</source>
      <translation type="unfinished">A ship instance must be selected before use this tool (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="215"/>
      <source>More than one ship has been selected (just the first one will be used)</source>
      <translation>選擇了超過一艘船(僅有第1艘會被使用)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="225"/>
      <source>A ship instance must be selected before use this tool (novalid ships found in the selected objects)</source>
      <translation type="unfinished">A ship instance must be selected before use this tool (novalid ships found in the selected objects)</translation>
    </message>
    <message>
      <location filename="InitGui.py" line="45"/>
      <source>Plot module is disabled, tools cannot graph output curves</source>
      <translation type="unfinished">Plot module is disabled, tools cannot graph output curves</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="89"/>
      <source>Failure detecting external faces from the ship object</source>
      <translation type="unfinished">Failure detecting external faces from the ship object</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="123"/>
      <source>A tank instance must be selected before using this tool (no objects selected)</source>
      <translation type="unfinished">A tank instance must be selected before using this tool (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="139"/>
      <source>More than one tank have been selected (the extra tanks will be ignored)</source>
      <translation type="unfinished">More than one tank have been selected (the extra tanks will be ignored)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="148"/>
      <source>A tank instance must be selected before using this tool (no valid tank found at the selected objects)</source>
      <translation type="unfinished">A tank instance must be selected before using this tool (no valid tank found at the selected objects)</translation>
    </message>
    <message>
      <location filename="TankInstance.py" line="133"/>
      <source>Tank volume operation failed. The tool is retrying that slightly moving the free surface position</source>
      <translation type="unfinished">Tank volume operation failed. The tool is retrying that slightly moving the free surface position</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="138"/>
      <source>A loading condition instance must be selected before using this tool (no objects selected)</source>
      <translation type="unfinished">A loading condition instance must be selected before using this tool (no objects selected)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="201"/>
      <source>Wrong Ship label! (no instances labeled as'{}' found)</source>
      <translation type="unfinished">Wrong Ship label! (no instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="209"/>
      <source>Ambiguous Ship label! ({} instances labeled as'{}' found)</source>
      <translation type="unfinished">Ambiguous Ship label! ({} instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="187"/>
      <source>More than one loading condition have been selected (the extra loading conditions will be ignored)</source>
      <translation type="unfinished">More than one loading condition have been selected (the extra loading conditions will be ignored)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="198"/>
      <source>A loading condition instance must be selected before using this tool (no valid loading condition found at the selected objects)</source>
      <translation type="unfinished">A loading condition instance must be selected before using this tool (no valid loading condition found at the selected objects)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="121"/>
      <source>Too much weight! The ship will never displace water enough</source>
      <translation type="unfinished">Too much weight! The ship will never displace water enough</translation>
    </message>
    <message>
      <location filename="Tools.py" line="234"/>
      <source>Wrong Weight label! (no instances labeled as'{}' found)</source>
      <translation type="unfinished">Wrong Weight label! (no instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="242"/>
      <source>Ambiguous Weight label! ({} instances labeled as'{}' found)</source>
      <translation type="unfinished">Ambiguous Weight label! ({} instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="254"/>
      <source>Invalid Weight! (the object labeled as'{}' is not a weight)</source>
      <translation type="unfinished">Invalid Weight! (the object labeled as'{}' is not a weight)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="279"/>
      <source>Wrong Tank label! (no instances labeled as'{}' found)</source>
      <translation type="unfinished">Wrong Tank label! (no instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="287"/>
      <source>Ambiguous Tank label! ({} instances labeled as'{}' found)</source>
      <translation type="unfinished">Ambiguous Tank label! ({} instances labeled as'{}' found)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="299"/>
      <source>Invalid Tank! (the object labeled as'{}' is not a tank)</source>
      <translation type="unfinished">Invalid Tank! (the object labeled as'{}' is not a tank)</translation>
    </message>
    <message>
      <location filename="Tools.py" line="53"/>
      <source>Computing capacity curves</source>
      <translation type="unfinished">Computing capacity curves</translation>
    </message>
    <message>
      <location filename="Tools.py" line="128"/>
      <source>Boolean operation failed when trying to get the underwater side. The tool is retrying such operation slightly moving the free surface position</source>
      <translation type="unfinished">Boolean operation failed when trying to get the underwater side. The tool is retrying such operation slightly moving the free surface position</translation>
    </message>
    <message>
      <location filename="Tools.py" line="201"/>
      <source>Part.OCCError: Transversal area computation failed</source>
      <translation type="unfinished">Part.OCCError: Transversal area computation failed</translation>
    </message>
    <message>
      <location filename="Tools.py" line="278"/>
      <source>ZeroDivisionError: Null volume found during the displacement computation!</source>
      <translation type="unfinished">ZeroDivisionError: Null volume found during the displacement computation!</translation>
    </message>
    <message>
      <location filename="Tools.py" line="378"/>
      <source>Part.OCCError: Floating area cannot be computed</source>
      <translation type="unfinished">Part.OCCError: Floating area cannot be computed</translation>
    </message>
    <message>
      <location filename="Tools.py" line="391"/>
      <source>ZeroDivisionError: Null area found during the floating area computation!</source>
      <translation type="unfinished">ZeroDivisionError: Null area found during the floating area computation!</translation>
    </message>
    <message>
      <location filename="Tools.py" line="465"/>
      <source>Part.OCCError: Main frame area cannot be computed</source>
      <translation type="unfinished">Part.OCCError: Main frame area cannot be computed</translation>
    </message>
    <message>
      <location filename="Tools.py" line="479"/>
      <source>ZeroDivisionError: Null area found during the main frame area coefficient computation!</source>
      <translation type="unfinished">ZeroDivisionError: Null area found during the main frame area coefficient computation!</translation>
    </message>
  </context>
  <context>
    <name>ship_create</name>
    <message>
      <location filename="Preview.py" line="69"/>
      <source>Base line</source>
      <translation>基準線</translation>
    </message>
    <message>
      <location filename="Preview.py" line="85"/>
      <source>Free surface</source>
      <translation>自由面</translation>
    </message>
    <message>
      <location filename="Preview.py" line="101"/>
      <source>Forward perpendicular</source>
      <translation type="unfinished">Forward perpendicular</translation>
    </message>
    <message>
      <location filename="Preview.py" line="117"/>
      <source>After perpendicular</source>
      <translation type="unfinished">After perpendicular</translation>
    </message>
    <message>
      <location filename="Preview.py" line="133"/>
      <source>Main frame</source>
      <translation>主框架</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="219"/>
      <source>Create a new ship</source>
      <translation>建立新的船舶</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="224"/>
      <source>Length</source>
      <translation>間距</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="229"/>
      <source>Breadth</source>
      <translation>寬度</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="234"/>
      <source>Draft</source>
      <translation>吃水</translation>
    </message>
  </context>
  <context>
    <name>ship_gz</name>
    <message>
      <location filename="ShipGui.py" line="199"/>
      <source>GZ curve computation</source>
      <translation type="unfinished">GZ curve computation</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="242"/>
      <source>Plot the GZ curve</source>
      <translation type="unfinished">Plot the GZ curve</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="247"/>
      <source>Maximum angle</source>
      <translation type="unfinished">Maximum angle</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="252"/>
      <source>Number of points</source>
      <translation>點數</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Variable trim</source>
      <translation type="unfinished">Variable trim</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="264"/>
      <source>The ship will be rotated to the equilibrium trim angle for each roll angle. It will significantly increase the required computing time</source>
      <translation type="unfinished">The ship will be rotated to the equilibrium trim angle for each roll angle. It will significantly increase the required computing time</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>GZ curve tool angle selected [deg]</source>
      <translation type="unfinished">GZ curve tool angle selected [deg]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="302"/>
      <source>GZ curve tool number of points selected</source>
      <translation type="unfinished">GZ curve tool number of points selected</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="317"/>
      <source>GZ curve tool variable trim angle selection</source>
      <translation type="unfinished">GZ curve tool variable trim angle selection</translation>
    </message>
  </context>
  <context>
    <name>ship_hydrostatic</name>
    <message>
      <location filename="TaskPanel.py" line="277"/>
      <source>Plot hydrostatics</source>
      <translation type="unfinished">Plot hydrostatics</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="282"/>
      <source>Trim</source>
      <translation>修剪</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="287"/>
      <source>Minimum draft</source>
      <translation>最小吃水量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="292"/>
      <source>Maximum draft</source>
      <translation>最大吃水量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="297"/>
      <source>Number of points</source>
      <translation>點數</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="413"/>
      <source>Hydrostatics tool trim selected</source>
      <translation type="unfinished">Hydrostatics tool trim selected</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="426"/>
      <source>Hydrostatics tool minimum draft selected [m]</source>
      <translation>選取流體靜力學最小吃水量 [m]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="439"/>
      <source>Hydrostatics tool maximum draft selected [m]</source>
      <translation>選取流體靜力學最大吃水量 [m]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="452"/>
      <source>Hydrostatics tool number of points selected</source>
      <translation type="unfinished">Hydrostatics tool number of points selected</translation>
    </message>
  </context>
  <context>
    <name>ship_load</name>
    <message>
      <location filename="TaskPanel.py" line="109"/>
      <source>Load example ship</source>
      <translation>載入範例船舶</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="113"/>
      <source>Select ship example geometry</source>
      <translation>選擇船舶幾何範例</translation>
    </message>
  </context>
  <context>
    <name>ship_loadcondition</name>
    <message>
      <location filename="ShipGui.py" line="182"/>
      <source>Create a new loading condition</source>
      <translation type="unfinished">Create a new loading condition</translation>
    </message>
    <message>
      <location filename="ShipGui.py" line="185"/>
      <source>Create a new load condition spreadsheet</source>
      <translation type="unfinished">Create a new load condition spreadsheet</translation>
    </message>
  </context>
  <context>
    <name>ship_outline</name>
    <message>
      <location filename="TaskPanel.py" line="236"/>
      <source>Outline draw</source>
      <translation>輪廓繪製</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="241"/>
      <source>Auto create</source>
      <translation>自動建立</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="246"/>
      <source>Delete all sections</source>
      <translation type="unfinished">Delete all sections</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="251"/>
      <source>Create sections</source>
      <translation type="unfinished">Create sections</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="257"/>
      <source>Transversal</source>
      <translation>橫向</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="263"/>
      <source>Longitudinal</source>
      <translation>縱向</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="269"/>
      <source>Water lines</source>
      <translation>水線</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="482"/>
      <source>Transversal section positions [m]</source>
      <translation type="unfinished">Transversal section positions [m]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="490"/>
      <source>Longitudinal section positions [m]</source>
      <translation type="unfinished">Longitudinal section positions [m]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="498"/>
      <source>Water line positions [m]</source>
      <translation>水線位置 [m]</translation>
    </message>
  </context>
  <context>
    <name>ship_tank</name>
    <message>
      <location filename="TankInstance.py" line="53"/>
      <source>True if it is a valid tank instance, False otherwise</source>
      <translation type="unfinished">True if it is a valid tank instance, False otherwise</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="163"/>
      <source>Create a new tank</source>
      <translation type="unfinished">Create a new tank</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="114"/>
      <source>Tanks objects can only be created on top of its geometry (no objects selected)</source>
      <translation type="unfinished">Tanks objects can only be created on top of its geometry (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="126"/>
      <source>No solids found in the selected objects</source>
      <translation type="unfinished">No solids found in the selected objects</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="143"/>
      <source>There are not ship objects to create weights into them</source>
      <translation type="unfinished">There are not ship objects to create weights into them</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="168"/>
      <source>Ship</source>
      <translation>船舶</translation>
    </message>
  </context>
  <context>
    <name>ship_weight</name>
    <message>
      <location filename="ShipGui.py" line="134"/>
      <source>Create a new ship weight</source>
      <translation type="unfinished">Create a new ship weight</translation>
    </message>
    <message>
      <location filename="WeightInstance.py" line="49"/>
      <source>True if it is a valid weight instance, False otherwise</source>
      <translation type="unfinished">True if it is a valid weight instance, False otherwise</translation>
    </message>
    <message>
      <location filename="WeightInstance.py" line="58"/>
      <source>Mass [kg]</source>
      <translation>質量 [kg]</translation>
    </message>
    <message>
      <location filename="WeightInstance.py" line="67"/>
      <source>Linear density [kg / m]</source>
      <translation>線密度 [kg / m]</translation>
    </message>
    <message>
      <location filename="WeightInstance.py" line="85"/>
      <source>Density [kg / m^3]</source>
      <translation>密度 [kg / m^3]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="118"/>
      <source>Weight objects can only be created on top of its geometry (no objects selected)</source>
      <translation type="unfinished">Weight objects can only be created on top of its geometry (no objects selected)</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="130"/>
      <source>No geometrical shapes found in the selected objects</source>
      <translation>無幾何造型於所選物件中</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="183"/>
      <source>There are not ship objects to create weights into them</source>
      <translation type="unfinished">There are not ship objects to create weights into them</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="216"/>
      <source>Create a new weight</source>
      <translation type="unfinished">Create a new weight</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="221"/>
      <source>Ship</source>
      <translation>船舶</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="227"/>
      <source>Mass</source>
      <translation>質量</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="233"/>
      <source>Linear density</source>
      <translation>線密度</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="239"/>
      <source>Area density</source>
      <translation>面密度</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="245"/>
      <source>Density</source>
      <translation>密度</translation>
    </message>
    <message>
      <location filename="WeightInstance.py" line="76"/>
      <source>Area density [kg / m^2]</source>
      <translation type="unfinished">Area density [kg / m^2]</translation>
    </message>
    <message>
      <location filename="TaskPanel.py" line="166"/>
      <source>Unknown object shapes selected</source>
      <translation type="unfinished">Unknown object shapes selected</translation>
    </message>
  </context>
</TS>
